# API wrapper for Ambientika devices

A simple API wrapper for the smart home air conditioning device(s) sold as Ambientika.
Probably incomplete because it is reverse engineered from a single device.
